summaryrefslogtreecommitdiff
path: root/sal/textenc/generate/cns116431992.pl
diff options
context:
space:
mode:
authorArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
committerArmin Le Grand <alg@apache.org>2014-07-14 19:09:11 +0000
commit3c1d4742e649fe9c8aed8c2817fe3e1f3364f298 (patch)
treee0c6e02c89aa9227726c9469da1001b3e29c41df /sal/textenc/generate/cns116431992.pl
parentc5c31e2aeaedbdf76e1f38d3c385e34f5ed875ca (diff)
Resync to trunk, windows non-pro buildaoo/aw080
Diffstat (limited to 'sal/textenc/generate/cns116431992.pl')
-rw-r--r--sal/textenc/generate/cns116431992.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/sal/textenc/generate/cns116431992.pl b/sal/textenc/generate/cns116431992.pl
index dfed86b3451c..cb882d1c5ab5 100644
--- a/sal/textenc/generate/cns116431992.pl
+++ b/sal/textenc/generate/cns116431992.pl
@@ -322,7 +322,7 @@ for ($cns_plane = 1; $cns_plane <= 16; ++$cns_plane)
$cns1_row = ($cns1 >> 8) & 0xFF;
$cns1_column = $cns1 & 0xFF;
# Do not map from Unicode to Fictious Character Set
# Extensions (Lunde, p. 131), if possible:
if ($cns_plane == 3
&& ($cns_row == 66 && $cns_column > 38
@@ -330,7 +330,7 @@ for ($cns_plane = 1; $cns_plane <= 16; ++$cns_plane)
{
print " (",
printUtf32($utf32),
- " to fictious ",
+ " to fictitious ",
printCns116431992($cns_plane,
$cns_row,
$cns_column),
@@ -350,7 +350,7 @@ for ($cns_plane = 1; $cns_plane <= 16; ++$cns_plane)
| $cns_column;
print " (",
printUtf32($utf32),
- " to fictious ",
+ " to fictitious ",
printCns116431992($cns1_plane,
$cns1_row,
$cns1_column),
@@ -322,7 +322,7 @@ for ($cns_plane = 1; $cns_plane <= 16; ++$cns_plane)
$cns1_row = ($cns1 >> 8) & 0xFF;
$cns1_column = $cns1 & 0xFF;
- # Do not map from Unicode to Fictious Character Set
+ # Do not map from Unicode to Fictitious Character Set
# Extensions (Lunde, p. 131), if possible:
if ($cns_plane == 3